@@ -27,7 +27,7 @@ static void create_controls(GConfClient* client);
 int
 main(int argc, char** argv)
 {
-  GConfError* error = NULL;
+  GError* error = NULL;
   GConfClient* client = NULL;
 
   gtk_init(&argc, &argv);
@@ -35,7 +35,7 @@ main(int argc, char** argv)
   if (!gconf_init(argc, argv, &error))
     {
       g_assert(error != NULL);
-      g_warning("GConf init failed:\n  %s", error->str);
+      g_warning("GConf init failed:\n  %s", error->message);
       return 1;
     }
 
@@ -55,14 +55,17 @@ main(int argc, char** argv)
 }
 
 static void
-entry_notify_func(GConfClient* client, guint cnxn_id, const gchar* key, GConfValue* value, gboolean is_default, gpointer user_data)
+entry_notify_func(GConfClient* client, guint cnxn_id,
+                  GConfEntry *gconf_entry,
+                  gpointer user_data)
 {
   GtkWidget* entry = user_data;
   
   g_return_if_fail(GTK_IS_ENTRY(entry));
 
   gtk_signal_handler_block_by_data(GTK_OBJECT(entry), client);
-  gtk_entry_set_text(GTK_ENTRY(entry), gconf_value_string(value));
+  gtk_entry_set_text(GTK_ENTRY(entry),
+                     gconf_value_get_string(gconf_entry->value));
   gtk_signal_handler_unblock_by_data(GTK_OBJECT(entry), client);
 }
 
@@ -133,6 +136,11 @@ entry_attached_to(GConfClient* client, const gchar* key)
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_box_pack_end(GTK_BOX(hbox), entry, FALSE, FALSE, 0);
 
+  /* Set sensitive according to whether the key is writable or not. */
+  gtk_widget_set_sensitive (entry,
+                            gconf_client_key_is_writable (client,
+                                                          key, NULL));
+  
   return hbox;
 }
 
